# Python SDK

This directory holds our Python SDK we share with our customers. The client is defined in `contextual_api_client.py`.

# Local Dev

Install [Poetry](https://python-poetry.org/docs/#installing-with-the-official-installer)

Run:

1. `poetry install`
2. `poetry shell`

In order to build the `.whl` run `petry build`. This will create a `dist/` folder with the artifacts.
